package cn.com.qmth.examcloud.service.core.api;

import java.io.IOException;
import java.util.List;

import cn.com.qmth.examcloud.common.util.excel.ExcelError;
import cn.com.qmth.examcloud.service.core.repo.OrgRepo;
import cn.com.qmth.examcloud.service.core.entity.Org;
import cn.com.qmth.examcloud.service.core.service.OrgService;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 机构服务API
 * Created by songyue on 17/1/14.
 */
@RestController
@RequestMapping("${app.api.root}/org")
public class OrgApi {

    @Autowired
    OrgRepo orgRepo;

    @Autowired
    OrgService orgService;

    @ApiOperation(value="查询所有机构")
    @GetMapping
    public ResponseEntity getAllOrg(){
        return new ResponseEntity(orgRepo.findAll(), HttpStatus.OK);
    }

    @ApiOperation(value="按ID查询机构",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity<Org> getOrgById(@PathVariable Long id){
        return new ResponseEntity(orgRepo.findById(id),HttpStatus.OK);
    }

    @ApiOperation(value="按parentId查询下属机构",notes="下属机构查询")
    @GetMapping("/sub/{parentId}")
    public ResponseEntity<Org> getOrgByParentId(@PathVariable Long parentId){
        return new ResponseEntity(orgRepo.findByParentId(parentId),HttpStatus.OK);
    }

    @ApiOperation(value="按rootId查询下属机构",notes="下属机构查询")
    @GetMapping("/allSub/{rootId}")
    public ResponseEntity<Org> getOrgByRootId(@PathVariable Long rootId){
        return new ResponseEntity(orgRepo.findByRootId(rootId),HttpStatus.OK);
    }

    @ApiOperation(value="新增机构",notes="新增")
    @PostMapping
    public ResponseEntity addSchool(@RequestBody Org org){
        return new ResponseEntity(orgRepo.save(org),HttpStatus.CREATED);
    }

    @ApiOperation(value="更新机构",notes="更新")
    @PutMapping
    public ResponseEntity updateSchool(@RequestBody Org org){
        return new ResponseEntity(orgRepo.save(org),HttpStatus.OK);
    }

    @ApiOperation(value="按ID删除机构",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteSchool(@PathVariable Long id){
        orgRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }
    
    @ApiOperation(value="按父ID导入子机构",notes="导入子机构")
    @PostMapping("/{id}/import")
    public ResponseEntity importLearnCenter(@PathVariable Long id,@RequestParam MultipartFile file){
    	try {
			List<ExcelError> excelErrors = orgService.importLearnCenter(id,file.getInputStream());
			return new ResponseEntity(excelErrors,HttpStatus.OK);
		} catch (IOException e) {
			e.printStackTrace();
			return new ResponseEntity(HttpStatus.INTERNAL_SERVER_ERROR);
		}
    }
}
